Struct tello_edu::TelloOptions
source · pub struct TelloOptions { /* private fields */ }Expand description
Tello drone connection and other usage options.
Implementations
sourceimpl TelloOptions
impl TelloOptions
sourcepub fn with_state(&mut self) -> TelloStateReceiver
pub fn with_state(&mut self) -> TelloStateReceiver
Request state updates from the drone.
nb As messages are sent to the UDP broadcast address 0.0.0.0 this only works in AP mode, ie using the drone’s own WiFi network
Returns the receiver end of the channel used to pass on updates
sourcepub fn with_video(&mut self) -> TelloVideoReceiver
pub fn with_video(&mut self) -> TelloVideoReceiver
Request video from the drone as a stream of h264-encoded 720p YUV frames.
nb As messages are sent to the UDP broadcast address 0.0.0.0 this only works in AP mode, ie using the drone’s own WiFi network
Returns the receiver end of the channel used to pass on frames